==> gramps-5.2.4.tgz: lib/python3.12/site-packages/gramps/gen/filters/rules/person/_hasothergender.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2002-2006  Donald N. Allingham
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

# -------------------------------------------------------------------------
#
# Standard Python modules
#
# -------------------------------------------------------------------------
from ....const import GRAMPS_LOCALE as glocale

_ = glocale.translation.gettext

# -------------------------------------------------------------------------
#
# Gramps modules
#
# -------------------------------------------------------------------------
from .. import Rule
from ....lib.person import Person


# -------------------------------------------------------------------------
#
# HasOtherGender
#
# -------------------------------------------------------------------------
class HasOtherGender(Rule):
    """Rule that checks for a person that has other gender"""

    name = _("People who are neither male nor female")
    category = _("General filters")
    description = _("Matches all people with other gender")

    def apply(self, db, person):
        return person.gender == Person.OTHER

==> gramps-6.0.5.tgz: lib/python3.12/site-packages/gramps/gen/filters/rules/person/_hasothergender.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2002-2006  Donald N. Allingham
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

# -------------------------------------------------------------------------
#
# Standard Python modules
#
# -------------------------------------------------------------------------
from ....const import GRAMPS_LOCALE as glocale

_ = glocale.translation.gettext

# -------------------------------------------------------------------------
#
# Gramps modules
#
# -------------------------------------------------------------------------
from .. import Rule
from ....lib.person import Person


# -------------------------------------------------------------------------
#
# Typing modules
#
# -------------------------------------------------------------------------
from ....db import Database


# -------------------------------------------------------------------------
#
# HasOtherGender
#
# -------------------------------------------------------------------------
class HasOtherGender(Rule):
    """Rule that checks for a person that has other gender"""

    name = _("People who are neither male nor female")
    category = _("General filters")
    description = _("Matches all people with other gender")

    def apply_to_one(self, db: Database, person: Person) -> bool:
        return person.gender == Person.OTHER
